@@ -9,24 +9,20 @@ import (
 	"strings"
 
 	"al.essio.dev/pkg/shellescape"
+	"github.com/coreos/go-semver/semver"
 	"github.com/lima-vm/lima/pkg/sshutil"
 	"github.com/lima-vm/lima/pkg/store"
 	"github.com/mattn/go-isatty"
-	"github.com/mattn/go-shellwords"
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
 )
 
-// Environment variable that allows configuring the command (alias) to execute
-// in place of the 'ssh' executable.
-const envShellSSH = "SSH"
-
 const shellHelp = `Execute shell in Lima
 
 lima command is provided as an alias for limactl shell $LIMA_INSTANCE. $LIMA_INSTANCE defaults to "` + DefaultInstanceName + `".
 
 By default, the first 'ssh' executable found in the host's PATH is used to connect to the Lima instance.
-A custom ssh alias can be used instead by setting the $` + envShellSSH + ` environment variable.
+A custom ssh alias can be used instead by setting the $` + sshutil.EnvShellSSH + ` environment variable.
 
 Hint: try --debug to show the detailed logs, if it seems hanging (mostly due to some SSH issue).
 `
@@ -141,31 +137,13 @@ func shellAction(cmd *cobra.Command, args []string) error {
 		)
 	}
 
-	var arg0 string
-	var arg0Args []string
-
-	if sshShell := os.Getenv(envShellSSH); sshShell != "" {
-		sshShellFields, err := shellwords.Parse(sshShell)
-		switch {
-		case err != nil:
-			logrus.WithError(err).Warnf("Failed to split %s variable into shell tokens. "+
-				"Falling back to 'ssh' command", envShellSSH)
-		case len(sshShellFields) > 0:
-			arg0 = sshShellFields[0]
-			if len(sshShellFields) > 1 {
-				arg0Args = sshShellFields[1:]
-			}
-		}
-	}
-
-	if arg0 == "" {
-		arg0, err = exec.LookPath("ssh")
-		if err != nil {
-			return err
-		}
+	arg0, arg0Args, err := sshutil.SSHArguments()
+	if err != nil {
+		return err
 	}
 
 	sshOpts, err := sshutil.SSHOpts(
+		arg0,
 		inst.Dir,
 		*inst.Config.User.Name,
 		*inst.Config.SSH.LoadDotSSHPubKeys,
@@ -184,8 +162,15 @@ func shellAction(cmd *cobra.Command, args []string) error {
 		// SendEnv config is cumulative, with already existing options in ssh_config
 		sshArgs = append(sshArgs, "-o", "SendEnv=COLORTERM")
 	}
+	logLevel := "ERROR"
+	// For versions older than OpenSSH 8.9p, LogLevel=QUIET was needed to
+	// avoid the "Shared connection to 127.0.0.1 closed." message with -t.
+	olderSSH := sshutil.DetectOpenSSHVersion(arg0).LessThan(*semver.New("8.9.0"))
+	if olderSSH {
+		logLevel = "QUIET"
+	}
 	sshArgs = append(sshArgs, []string{
-		"-o", "LogLevel=ERROR",
+		"-o", fmt.Sprintf("LogLevel=%s", logLevel),
 		"-p", strconv.Itoa(inst.SSHLocalPort),
 		inst.SSHAddress,
 		"--",
