@@ -30,7 +30,7 @@ import (
 var HideProgress bool
 
 // hideBar is used only for testing.
-func hideBar(bar *pb.ProgressBar) {
+func hideBar(bar *progressbar.ProgressBar) {
 	bar.Set(pb.Static, true)
 }
 
@@ -58,6 +58,15 @@ type options struct {
 	expectedDigest digest.Digest
 }
 
+func (o *options) apply(opts []Opt) error {
+	for _, f := range opts {
+		if err := f(o); err != nil {
+			return err
+		}
+	}
+	return nil
+}
+
 type Opt func(*options) error
 
 // WithCache enables caching using filepath.Join(os.UserCacheDir(), "lima") as the cache dir.
@@ -165,15 +174,14 @@ func readTime(path string) time.Time {
 // The local path can be an empty string for "caching only" mode.
 func Download(ctx context.Context, local, remote string, opts ...Opt) (*Result, error) {
 	var o options
-	for _, f := range opts {
-		if err := f(&o); err != nil {
-			return nil, err
-		}
+	if err := o.apply(opts); err != nil {
+		return nil, err
 	}
+
 	var localPath string
 	if local == "" {
 		if o.cacheDir == "" {
-			return nil, fmt.Errorf("caching-only mode requires the cache directory to be specified")
+			return nil, errors.New("caching-only mode requires the cache directory to be specified")
 		}
 	} else {
 		var err error
@@ -221,6 +229,31 @@ func Download(ctx context.Context, local, remote string, opts ...Opt) (*Result,
 		return res, nil
 	}
 
+	shad := cacheDirectoryPath(o.cacheDir, remote)
+	if err := os.MkdirAll(shad, 0o700); err != nil {
+		return nil, err
+	}
+
+	var res *Result
+	err := lockutil.WithDirLock(shad, func() error {
+		var err error
+		res, err = getCached(ctx, localPath, remote, o)
+		if err != nil {
+			return err
+		}
+		if res != nil {
+			return nil
+		}
+		res, err = fetch(ctx, localPath, remote, o)
+		return err
+	})
+	return res, err
+}
+
+// getCached tries to copy the file from the cache to local path. Return result,
+// nil if the file was copied, nil, nil if the file is not in the cache or the
+// cache needs update, or nil, error on fatal error.
+func getCached(ctx context.Context, localPath, remote string, o options) (*Result, error) {
 	shad := cacheDirectoryPath(o.cacheDir, remote)
 	shadData := filepath.Join(shad, "data")
 	shadTime := filepath.Join(shad, "time")
@@ -229,53 +262,62 @@ func Download(ctx context.Context, local, remote string, opts ...Opt) (*Result,
 	if err != nil {
 		return nil, err
 	}
-	if _, err := os.Stat(shadData); err == nil {
-		logrus.Debugf("file %q is cached as %q", localPath, shadData)
-		useCache := true
-		if _, err := os.Stat(shadDigest); err == nil {
-			logrus.Debugf("Comparing digest %q with the cached digest file %q, not computing the actual digest of %q",
-				o.expectedDigest, shadDigest, shadData)
-			if err := validateCachedDigest(shadDigest, o.expectedDigest); err != nil {
-				return nil, err
-			}
-			if err := copyLocal(ctx, localPath, shadData, ext, o.decompress, "", ""); err != nil {
+	if _, err := os.Stat(shadData); err != nil {
+		return nil, nil
+	}
+	ext := path.Ext(remote)
+	logrus.Debugf("file %q is cached as %q", localPath, shadData)
+	if _, err := os.Stat(shadDigest); err == nil {
+		logrus.Debugf("Comparing digest %q with the cached digest file %q, not computing the actual digest of %q",
+			o.expectedDigest, shadDigest, shadData)
+		if err := validateCachedDigest(shadDigest, o.expectedDigest); err != nil {
+			return nil, err
+		}
+		if err := copyLocal(ctx, localPath, shadData, ext, o.decompress, "", ""); err != nil {
+			return nil, err
+		}
+	} else {
+		if match, lmCached, lmRemote, err := matchLastModified(ctx, shadTime, remote); err != nil {
+			logrus.WithError(err).Info("Failed to retrieve last-modified for cached digest-less image; using cached image.")
+		} else if match {
+			if err := copyLocal(ctx, localPath, shadData, ext, o.decompress, o.description, o.expectedDigest); err != nil {
 				return nil, err
 			}
 		} else {
-			if match, lmCached, lmRemote, err := matchLastModified(ctx, shadTime, remote); err != nil {
-				logrus.WithError(err).Info("Failed to retrieve last-modified for cached digest-less image; using cached image.")
-			} else if match {
-				if err := copyLocal(ctx, localPath, shadData, ext, o.decompress, o.description, o.expectedDigest); err != nil {
-					return nil, err
-				}
-			} else {
-				logrus.Infof("Re-downloading digest-less image: last-modified mismatch (cached: %q, remote: %q)", lmCached, lmRemote)
-				useCache = false
-			}
-		}
-		if useCache {
-			res := &Result{
-				Status:          StatusUsedCache,
-				CachePath:       shadData,
-				LastModified:    readTime(shadTime),
-				ContentType:     readFile(shadType),
-				ValidatedDigest: o.expectedDigest != "",
-			}
-			return res, nil
+			logrus.Infof("Re-downloading digest-less image: last-modified mismatch (cached: %q, remote: %q)", lmCached, lmRemote)
+			return nil, nil
 		}
 	}
-	if err := os.MkdirAll(shad, 0o700); err != nil {
+	res := &Result{
+		Status:          StatusUsedCache,
+		CachePath:       shadData,
+		LastModified:    readTime(shadTime),
+		ContentType:     readFile(shadType),
+		ValidatedDigest: o.expectedDigest != "",
+	}
+	return res, nil
+}
+
+// fetch downloads remote to the cache and copy the cached file to local path.
+func fetch(ctx context.Context, localPath, remote string, o options) (*Result, error) {
+	shad := cacheDirectoryPath(o.cacheDir, remote)
+	shadData := filepath.Join(shad, "data")
+	shadTime := filepath.Join(shad, "time")
+	shadType := filepath.Join(shad, "type")
+	shadDigest, err := cacheDigestPath(shad, o.expectedDigest)
+	if err != nil {
 		return nil, err
 	}
+	ext := path.Ext(remote)
 	shadURL := filepath.Join(shad, "url")
-	if err := writeFirst(shadURL, []byte(remote), 0o644); err != nil {
+	if err := os.WriteFile(shadURL, []byte(remote), 0o644); err != nil {
 		return nil, err
 	}
 	if err := downloadHTTP(ctx, shadData, shadTime, shadType, remote, o.description, o.expectedDigest); err != nil {
 		return nil, err
 	}
 	if shadDigest != "" && o.expectedDigest != "" {
-		if err := writeFirst(shadDigest, []byte(o.expectedDigest.String()), 0o644); err != nil {
+		if err := os.WriteFile(shadDigest, []byte(o.expectedDigest.String()), 0o644); err != nil {
 			return nil, err
 		}
 	}
@@ -301,16 +343,14 @@ func Download(ctx context.Context, local, remote string, opts ...Opt) (*Result,
 // When the cache path already exists, Cached returns Result with StatusUsedCache.
 func Cached(remote string, opts ...Opt) (*Result, error) {
 	var o options
-	for _, f := range opts {
-		if err := f(&o); err != nil {
-			return nil, err
-		}
+	if err := o.apply(opts); err != nil {
+		return nil, err
 	}
 	if o.cacheDir == "" {
-		return nil, fmt.Errorf("caching-only mode requires the cache directory to be specified")
+		return nil, errors.New("caching-only mode requires the cache directory to be specified")
 	}
 	if IsLocal(remote) {
-		return nil, fmt.Errorf("local files are not cached")
+		return nil, errors.New("local files are not cached")
 	}
 
 	shad := cacheDirectoryPath(o.cacheDir, remote)
@@ -321,18 +361,33 @@ func Cached(remote string, opts ...Opt) (*Result, error) {
 	if err != nil {
 		return nil, err
 	}
+
+	// Checking if data file exists is safe without locking.
 	if _, err := os.Stat(shadData); err != nil {
 		return nil, err
 	}
-	if _, err := os.Stat(shadDigest); err != nil {
-		if err := validateCachedDigest(shadDigest, o.expectedDigest); err != nil {
-			return nil, err
-		}
-	} else {
-		if err := validateLocalFileDigest(shadData, o.expectedDigest); err != nil {
-			return nil, err
-		}
+
+	// But validating the digest or the data file must take the lock to avoid races
+	// with parallel downloads.
+	if err := os.MkdirAll(shad, 0o700); err != nil {
+		return nil, err
 	}
+	err = lockutil.WithDirLock(shad, func() error {
+		if _, err := os.Stat(shadDigest); err != nil {
+			if err := validateCachedDigest(shadDigest, o.expectedDigest); err != nil {
+				return err
+			}
+		} else {
+			if err := validateLocalFileDigest(shadData, o.expectedDigest); err != nil {
+				return err
+			}
+		}
+		return nil
+	})
+	if err != nil {
+		return nil, err
+	}
+
 	res := &Result{
 		Status:          StatusUsedCache,
 		CachePath:       shadData,
@@ -376,7 +431,7 @@ func IsLocal(s string) bool {
 //   - Expand a leading `~`, or convert relative to absolute name
 func canonicalLocalPath(s string) (string, error) {
 	if s == "" {
-		return "", fmt.Errorf("got empty path")
+		return "", errors.New("got empty path")
 	}
 	if !IsLocal(s) {
 		return "", fmt.Errorf("got non-local path: %q", s)
@@ -533,7 +588,7 @@ func validateCachedDigest(shadDigest string, expectedDigest digest.Digest) error
 
 func validateLocalFileDigest(localPath string, expectedDigest digest.Digest) error {
 	if localPath == "" {
-		return fmt.Errorf("validateLocalFileDigest: got empty localPath")
+		return errors.New("validateLocalFileDigest: got empty localPath")
 	}
 	if expectedDigest == "" {
 		return nil
@@ -596,7 +651,7 @@ func matchLastModified(ctx context.Context, lastModifiedPath, url string) (match
 
 func downloadHTTP(ctx context.Context, localPath, lastModified, contentType, url, description string, expectedDigest digest.Digest) error {
 	if localPath == "" {
-		return fmt.Errorf("downloadHTTP: got empty localPath")
+		return errors.New("downloadHTTP: got empty localPath")
 	}
 	logrus.Debugf("downloading %q into %q", url, localPath)
 
@@ -606,13 +661,13 @@ func downloadHTTP(ctx context.Context, localPath, lastModified, contentType, url
 	}
 	if lastModified != "" {
 		lm := resp.Header.Get("Last-Modified")
-		if err := writeFirst(lastModified, []byte(lm), 0o644); err != nil {
+		if err := os.WriteFile(lastModified, []byte(lm), 0o644); err != nil {
 			return err
 		}
 	}
 	if contentType != "" {
 		ct := resp.Header.Get("Content-Type")
-		if err := writeFirst(contentType, []byte(ct), 0o644); err != nil {
+		if err := os.WriteFile(contentType, []byte(ct), 0o644); err != nil {
 			return err
 		}
 	}
@@ -673,19 +728,7 @@ func downloadHTTP(ctx context.Context, localPath, lastModified, contentType, url
 		return err
 	}
 
-	// If localPath was created by a parallel download keep it. Replacing it
-	// while another process is copying it to the destination may fail the
-	// clonefile syscall. We use a lock to ensure that only one process updates
-	// data, and when we return data file exists.
-
-	return lockutil.WithDirLock(filepath.Dir(localPath), func() error {
-		if _, err := os.Stat(localPath); err == nil {
-			return nil
-		} else if !errors.Is(err, os.ErrNotExist) {
-			return err
-		}
-		return os.Rename(localPathTmp, localPath)
-	})
+	return os.Rename(localPathTmp, localPath)
 }
 
 var tempfileCount atomic.Uint64
@@ -700,28 +743,14 @@ func perProcessTempfile(path string) string {
 	return fmt.Sprintf("%s.tmp.%d.%d", path, os.Getpid(), tempfileCount.Add(1))
 }
 
-// writeFirst writes data to path unless path already exists.
-func writeFirst(path string, data []byte, perm os.FileMode) error {
-	return lockutil.WithDirLock(filepath.Dir(path), func() error {
-		if _, err := os.Stat(path); err == nil {
-			return nil
-		} else if !errors.Is(err, os.ErrNotExist) {
-			return err
-		}
-		return os.WriteFile(path, data, perm)
-	})
-}
-
 // CacheEntries returns a map of cache entries.
 // The key is the SHA256 of the URL.
 // The value is the path to the cache entry.
-func CacheEntries(opt ...Opt) (map[string]string, error) {
+func CacheEntries(opts ...Opt) (map[string]string, error) {
 	entries := make(map[string]string)
 	var o options
-	for _, f := range opt {
-		if err := f(&o); err != nil {
-			return nil, err
-		}
+	if err := o.apply(opts); err != nil {
+		return nil, err
 	}
 	if o.cacheDir == "" {
 		return entries, nil
@@ -750,12 +779,10 @@ func CacheKey(remote string) string {
 }
 
 // RemoveAllCacheDir removes the cache directory.
-func RemoveAllCacheDir(opt ...Opt) error {
+func RemoveAllCacheDir(opts ...Opt) error {
 	var o options
-	for _, f := range opt {
-		if err := f(&o); err != nil {
-			return err
-		}
+	if err := o.apply(opts); err != nil {
+		return err
 	}
 	if o.cacheDir == "" {
 		return nil
