@@ -3,6 +3,7 @@ package driverutil
 import (
 	"github.com/lima-vm/lima/pkg/limayaml"
 	"github.com/lima-vm/lima/pkg/vz"
+	"github.com/lima-vm/lima/pkg/wsl2"
 )
 
 // Drivers returns the available drivers.
@@ -11,5 +12,8 @@ func Drivers() []string {
 	if vz.Enabled {
 		drivers = append(drivers, limayaml.VZ)
 	}
+	if wsl2.Enabled {
+		drivers = append(drivers, limayaml.WSL2)
+	}
 	return drivers
 }
