@@ -8,6 +8,7 @@ import (
 
 type Agent interface {
 	Info(ctx context.Context) (*api.Info, error)
-	Events(ctx context.Context, ch chan api.Event)
-	LocalPorts(ctx context.Context) ([]api.IPPort, error)
+	Events(ctx context.Context, ch chan *api.Event)
+	LocalPorts(ctx context.Context) ([]*api.IPPort, error)
+	HandleInotify(event *api.Inotify)
 }
