@@ -20,7 +20,7 @@ func (a *HostAgent) setupMounts() ([]*mount, error) {
 		res  []*mount
 		errs []error
 	)
-	for _, f := range a.y.Mounts {
+	for _, f := range a.instConfig.Mounts {
 		m, err := a.setupMount(f)
 		if err != nil {
 			errs = append(errs, err)
@@ -37,7 +37,7 @@ func (a *HostAgent) setupMount(m limayaml.Mount) (*mount, error) {
 		return nil, err
 	}
 
-	mountPoint, err := localpathutil.Expand(m.MountPoint)
+	mountPoint, err := localpathutil.Expand(*m.MountPoint)
 	if err != nil {
 		return nil, err
 	}
