@@ -56,7 +56,7 @@ var (
 
 func defaultCPUType() CPUType {
 	cpuType := map[Arch]string{
-		AARCH64: "cortex-a72",
+		AARCH64: "cortex-a76", // available since QEMU 7.1 (Aug 2022)
 		ARMV7L:  "cortex-a7",
 		// Since https://github.com/lima-vm/lima/pull/494, we use qemu64 cpu for better emulation of x86_64.
 		X8664:   "qemu64",
@@ -73,6 +73,10 @@ func defaultCPUType() CPUType {
 		if arch == X8664 && runtime.GOOS == "darwin" {
 			switch cpuType[arch] {
 			case "host", "max":
+				// disable AVX-512, since it requires trapping instruction faults in guest
+				// Enterprise Linux requires either v2 (SSE4) or v3 (AVX2), but not yet v4.
+				cpuType[arch] += ",-avx512vl"
+
 				// Disable pdpe1gb on Intel Mac
 				// https://github.com/lima-vm/lima/issues/1485
 				// https://stackoverflow.com/a/72863744/5167443
@@ -205,6 +209,9 @@ func FillDefault(y, d, o *LimaYAML, filePath string, warn bool) {
 	if y.User.Home == nil {
 		y.User.Home = d.User.Home
 	}
+	if y.User.Shell == nil {
+		y.User.Shell = d.User.Shell
+	}
 	if y.User.UID == nil {
 		y.User.UID = d.User.UID
 	}
@@ -217,6 +224,9 @@ func FillDefault(y, d, o *LimaYAML, filePath string, warn bool) {
 	if o.User.Home != nil {
 		y.User.Home = o.User.Home
 	}
+	if o.User.Shell != nil {
+		y.User.Shell = o.User.Shell
+	}
 	if o.User.UID != nil {
 		y.User.UID = o.User.UID
 	}
@@ -232,6 +242,9 @@ func FillDefault(y, d, o *LimaYAML, filePath string, warn bool) {
 		y.User.Home = ptr.Of(osutil.LimaUser(existingLimaVersion, warn).HomeDir)
 		warn = false
 	}
+	if y.User.Shell == nil {
+		y.User.Shell = ptr.Of("/bin/bash")
+	}
 	if y.User.UID == nil {
 		uidString := osutil.LimaUser(existingLimaVersion, warn).Uid
 		if uid, err := strconv.ParseUint(uidString, 10, 32); err == nil {
@@ -886,7 +899,7 @@ func executeGuestTemplate(format, instDir string, user User, param map[string]st
 	tmpl, err := template.New("").Parse(format)
 	if err == nil {
 		name := filepath.Base(instDir)
-		data := map[string]interface{}{
+		data := map[string]any{
 			"Name":     name,
 			"Hostname": identifierutil.HostnameFromInstName(name), // TODO: support customization
 			"UID":      *user.UID,
@@ -906,7 +919,7 @@ func executeHostTemplate(format, instDir string, param map[string]string) (bytes
 	tmpl, err := template.New("").Parse(format)
 	if err == nil {
 		limaHome, _ := dirnames.LimaDir()
-		data := map[string]interface{}{
+		data := map[string]any{
 			"Dir":  instDir,
 			"Name": filepath.Base(instDir),
 			// TODO: add hostname fields for the host and the guest
@@ -1174,18 +1187,7 @@ func IsAccelOS() bool {
 	return false
 }
 
-var (
-	hasSMEDarwin     bool
-	hasSMEDarwinOnce sync.Once
-)
-
-func init() {
-	hasSMEDarwinOnce.Do(func() {
-		hasSMEDarwin = hasSMEDarwinFn()
-	})
-}
-
-func hasSMEDarwinFn() bool {
+var hasSMEDarwin = sync.OnceValue(func() bool {
 	if runtime.GOOS != "darwin" || runtime.GOARCH != "arm64" {
 		return false
 	}
@@ -1195,19 +1197,24 @@ func hasSMEDarwinFn() bool {
 		logrus.WithError(err).Debug("failed to check hw.optional.arm.FEAT_SME")
 	}
 	return s == "1"
-}
+})
 
 func HasHostCPU() bool {
 	switch runtime.GOOS {
 	case "darwin":
-		if hasSMEDarwin {
-			// SME is available since Apple M4 running macOS 15.2.
-			//
-			// However, QEMU is not ready to handle SME yet.
+		if hasSMEDarwin() {
+			// [2025-02-05]
+			// SME is available since Apple M4 running macOS 15.2, but it was broken on macOS 15.2.
+			// It has been fixed in 15.3.
 			//
 			// https://github.com/lima-vm/lima/issues/3032
 			// https://gitlab.com/qemu-project/qemu/-/issues/2665
 			// https://gitlab.com/qemu-project/qemu/-/issues/2721
+
+			// [2025-02-12]
+			// SME got broken again after upgrading QEMU from 9.2.0 to 9.2.1 (Homebrew bottle).
+			// Possibly this regression happened in some build process rather than in QEMU itself?
+			// https://github.com/lima-vm/lima/issues/3226
 			return false
 		}
 		return true
