@@ -4,12 +4,13 @@ import (
 	"fmt"
 	"os/exec"
 	"strings"
+	"sync"
 
 	"github.com/coreos/go-semver/semver"
 )
 
 // ProductVersion returns the macOS product version like "12.3.1".
-func ProductVersion() (*semver.Version, error) {
+var ProductVersion = sync.OnceValues(func() (*semver.Version, error) {
 	cmd := exec.Command("sw_vers", "-productVersion")
 	// output is like "12.3.1\n"
 	b, err := cmd.Output()
@@ -26,4 +27,4 @@ func ProductVersion() (*semver.Version, error) {
 		return nil, fmt.Errorf("failed to parse macOS version %q: %w", verTrimmed, err)
 	}
 	return verSem, nil
-}
+})
